@@ -2,7 +2,8 @@
 
 ### For general types.
 spmd.bcast.object <- function(x,
-    rank.source = .SPMD.CT$rank.source, comm = .SPMD.CT$comm){
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
   if(spmd.comm.rank(comm) == rank.source){
     x.raw <- serialize(x, NULL)
     spmd.bcast.integer(length(x.raw), rank.source = rank.source, comm = comm)
@@ -18,7 +19,8 @@ spmd.bcast.object <- function(x,
 
 ### For array only.
 spmd.bcast.array <- function(x,
-    rank.source = .SPMD.CT$rank.source, comm = .SPMD.CT$comm){
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
   if(spmd.comm.rank(comm) == rank.source){
     spmd.bcast.integer(length(dim(x)), rank.source = rank.source, comm = comm)
     spmd.bcast.integer(dim(x), rank.source = rank.source, comm = comm)
@@ -64,3 +66,18 @@ spmd.bcast.array <- function(x,
   spmd.bcast.object(x, rank.source = rank.source, comm = comm) 
 } # End of spmd.bcast.array().
 
+### For message.
+spmd.bcast.message <- function(x,
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
+  if(spmd.comm.rank(comm) == rank.source){
+    spmd.bcast.integer(nchar(x[1]), rank.source = rank.source, comm = comm)
+    spmd.bcast.string(x[1], rank.source = rank.source, comm = comm)
+    return(x[1])
+  } else{
+    x.count <- spmd.bcast.integer(integer(1), rank.source = rank.source,
+                                  comm = comm)
+    spmd.bcast.string(paste0(rep(" ", x.count), collapse = ""),
+                      rank.source = rank.source, comm = comm)
+  }
+} # End of spmd.bcast.message().
